# Changelog — free/ai/ai_assistant

## 0.1.11 — Automated patch release triggered by content hash change (2026-02-14)

- chore: Automated patch release triggered by content hash change

## 0.1.10 — Automated patch release triggered by content hash change (2026-02-12)

- chore: Automated patch release triggered by content hash change

## 0.1.9 — NestJS stability and provider extensibility (2026-02-12)

- fix: auto-register `AiAssistantModule` in NestJS `src/modules/index.ts` via snippet injection
- feat: expose `hasProvider()` and public `registerProvider()` in NestJS service template
- feat: add built-in `openai` provider type support in NestJS service template (`api_key` option or
  `OPENAI_API_KEY`)

## 0.1.8 — Automated patch release triggered by content hash change (2026-02-11)

- chore: Automated patch release triggered by content hash change

## 0.1.7 — Automated patch release triggered by content hash change (2026-01-04)

- chore: Automated patch release triggered by content hash change

## 0.1.6 — Automated patch release triggered by content hash change (2026-01-04)

- chore: Automated patch release triggered by content hash change

## 0.1.5 — Automated patch release triggered by content hash change (2026-01-02)

- chore: Automated patch release triggered by content hash change

## 0.1.4 — Automated patch release triggered by content hash change (2025-12-28)

- chore: Automated patch release triggered by content hash change

## 0.1.3 — Automated patch release triggered by content hash change (2025-12-25)

- chore: Automated patch release triggered by content hash change

## 0.1.2 — Automated patch release triggered by content hash change (2025-12-24)

- chore: Automated patch release triggered by content hash change

## 0.1.1 — Automated patch release triggered by content hash change (2025-12-23)

- chore: Automated patch release triggered by content hash change

## 0.1.0 — Initial baseline (2025-12-04)

- Initial public baseline.
